Module: ClickHouse::SQL::Part
- Included in:
- Fragment, Join, Query, Raw, SelectItem, SelectQuery, Setting, Table
- Defined in:
- lib/clickhouse/sql/part.rb
Overview
Internal protocol for renderable ClickHouse::SQL builder parts.
Instance Method Summary collapse
-
#placeholder_types ⇒ Hash{Symbol=>String}
Returns ClickHouse placeholder types used by this part.
-
#placeholders ⇒ Hash{Symbol=>Object}
Returns typed placeholder values used by this part.
-
#to_redacted_sql(bind_index_manager = ClickHouse::SQL::BindIndexManager.new) ⇒ String
Renders this part with typed placeholders replaced by bind markers.
-
#to_sql ⇒ String
Renders this part with typed placeholders intact.
Instance Method Details
#placeholder_types ⇒ Hash{Symbol=>String}
Returns ClickHouse placeholder types used by this part.
32 33 34 |
# File 'lib/clickhouse/sql/part.rb', line 32 def placeholder_types {} end |
#placeholders ⇒ Hash{Symbol=>Object}
Returns typed placeholder values used by this part.
25 26 27 |
# File 'lib/clickhouse/sql/part.rb', line 25 def placeholders {} end |
#to_redacted_sql(bind_index_manager = ClickHouse::SQL::BindIndexManager.new) ⇒ String
Renders this part with typed placeholders replaced by bind markers.
18 19 20 |
# File 'lib/clickhouse/sql/part.rb', line 18 def to_redacted_sql(bind_index_manager = ClickHouse::SQL::BindIndexManager.new) raise NotImplementedError end |
#to_sql ⇒ String
Renders this part with typed placeholders intact.
10 11 12 |
# File 'lib/clickhouse/sql/part.rb', line 10 def to_sql raise NotImplementedError end |